netapp_ontap.models.disk_virtual API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.disk_virtual`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DiskVirtualSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DiskVirtual object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `container: str GET`

    Container name of the virtual disk.

    Example: nviet12122018113936-rg

  `object: str GET`

    Object name of the virtual disk.

    Example: f1fu63se

  `storage_account: str GET`

    Storage account name of the virtual disk.

    Example: nviet12122018113936ps

  `target_address: str GET`

    Target address of the virtual disk.